@@ -10,7 +10,11 @@
 //! [2]: https://www.kernel.org/doc/html/latest/admin-guide/sysfs-rules.html
 
 pub use battery::Battery;
+pub use battery::BatteryStats;
+pub use battery::BatteryStatsRaw;
+pub use health::Health;
 pub use soc::SoC;
 
 pub mod battery;
+pub mod health;
 pub mod soc;
