@@ -13,12 +13,18 @@ pub enum PwrError {
     #[error(transparent)]
     GenericError(#[from] std::io::Error),
 
+    #[error("Failed to parse: {0}")]
+    ParseError(String),
+
     #[error("Not implemented yet: {0}")]
     NotImplemented(String),
 
-    #[error("Not a valid SoC: {0}")]
+    #[error("Not a valid SoC: {0} %")]
     InvalidSoC(f32),
 
+    #[error("Not a valid battery health: {0} %")]
+    InvalidHealth(f32),
+
     #[error("No battery found under: {0}")]
     NoBattery(PathBuf),
 }
